**Example 1: 修改应用**

修改应用的相关信息

Input: 

```
tccli lcic ModifyApp --cli-unfold-argument  \
    --SdkAppId 1 \
    --Callback abc \
    --CallbackKey abc
```

Output: 
```
{
    "Response": {
        "RequestId": "e574aae1-lp02-4225-a2f8-9032h7199f5f0"
    }
}
```

